@@ -6,7 +6,7 @@ use WebminCore;
 &foreign_require("net", "net-lib.pl");
 
 # Get the detected ipf version
-if (open(VERSION, "$module_config_directory/version")) {
+if (open(VERSION, "<$module_config_directory/version")) {
 	chop($ipf_version = <VERSION>);
 	close(VERSION);
 	}
@@ -47,7 +47,7 @@ local $file = $_[0] || $config{'ipf_conf'};
 return $get_config_cache{$file} if ($get_config_cache{$file});
 local @rv;
 local $lnum = 0;
-open(FILE, $file);
+open(FILE, "<".$file);
 while(<FILE>) {
 	# Read each line, splitting into words
 	s/\r|\n//g;
@@ -76,14 +76,14 @@ while(<FILE>) {
 		$rule->{'action'} = shift(@w);
 		if ($rule->{'action'} eq "block") {
 			# Block can have ICMP return type parameter
+			print STDERR $w[0],"\n";
 			if ($w[0] eq "return-rst") {
 				shift(@w);
 				$rule->{'block-return'} = "rst";
 				}
 			elsif ($w[0] eq "return-icmp" ||
 			       $w[0] eq "return-icmp-as-dest") {
-				# XXX is this correct? ie.
-				# return-icmp ( srcfail )
+				# Handle action like return-icmp ( net-unr )
 				$rule->{'block-return-dest'} = 1
 					if ($w[0] eq "return-icmp-as-dest");
 				shift(@w);
@@ -91,6 +91,13 @@ while(<FILE>) {
 				$rule->{'block-return'} = shift(@w);
 				shift(@w);	# skip )
 				}
+			elsif ($w[0] =~ /^(return-icmp|return-icmp-as-dest)\((\S+)\)/) {
+				# Same as above, with no spaces
+				$rule->{'block-return-dest'} = 1
+					if ($1 eq "return-icmp-as-dest");
+				$rule->{'block-return'} = $2;
+				shift(@w);
+				}
 			}
 		elsif ($rule->{'action'} eq "log") {
 			# Log action can have several options
@@ -173,12 +180,22 @@ while(<FILE>) {
 			$rule->{'ttl'} = shift(@w);
 			}
 
+		# Inet keyword can appear before proto, but does nothing
+		if ($w[0] eq "inet") {
+			shift(@w);
+			}
+
 		# Parse protocol
 		if ($w[0] eq "proto") {
 			shift(@w);
 			$rule->{'proto'} = shift(@w);
 			}
 
+		# Skip inet keyword, which as far as I know does nothing
+		if ($w[0] eq "inet") {
+			shift(@w);
+			}
+
 		# Parse from/to section
 		if ($w[0] eq "all") {
 			shift(@w);
@@ -197,7 +214,8 @@ while(<FILE>) {
 				$cmt .= $nocmt;
 				goto nextline;
 				}
-			&error("error parsing IPF line $_ at $w[0] line $lnum");
+			&error("error parsing IPF line $_ at $w[0] line $lnum ".
+			       " : remainder ".join(" ", @w));
 			}
 
 		# Parse ip options
@@ -933,7 +951,7 @@ sub get_ipnat_config
 {
 local $file = $_[0] || $config{'ipnat_conf'};
 return $get_ipnat_config_cache{$file} if ($get_ipnat_config_cache{$file});
-open(FILE, $file);
+open(FILE, "<".$file);
 while(<FILE>) {
 	# Read each line, splitting into words
 	s/\r|\n//g;
@@ -1173,7 +1191,7 @@ sub list_protocols
 {
 local @stdprotos = ( 'tcp', 'udp', 'icmp' );
 local @otherprotos;
-open(PROTOS, "/etc/protocols");
+open(PROTOS, "</etc/protocols");
 while(<PROTOS>) {
 	s/\r|\n//g;
 	s/#.*$//;
@@ -1216,9 +1234,17 @@ if ($config{'smf'}) {
 	       $state eq 'disabled' || $state eq 'offline' ||
 	        $state eq 'maintenance' ? 1 : 0;
 	}
+elsif ($gconfig{'os_type'} eq 'freebsd') {
+	# Check for built-in rc config
+	&foreign_require("init");
+	local @rc = &init::get_rc_conf();
+	local ($rc) = grep { $_->{'name'} eq 'ipfilter_enable' &&
+			     $_->{'value'} eq 'YES' } @rc;
+	return $rc ? 2 : 1;
+	}
 else {
 	# Look at init script
-	&foreign_require("init", "init-lib.pl");
+	&foreign_require("init");
 	return &init::action_status($init_script);
 	}
 }
@@ -1237,6 +1263,17 @@ if ($config{'smf'}) {
 				    [ $config{'smf'} ]);
 		}
 	}
+elsif ($gconfig{'os_type'} eq 'freebsd') {
+	# Use built-in config
+	&foreign_require("init");
+	&init::save_rc_conf("ipfilter_enable", "YES");
+	&init::save_rc_conf("ipfilter_rules", $config{'ipf_conf'});
+	my $natrules = &get_ipnat_config();
+	if (@$natrules) {
+		&init::save_rc_conf("ipnat_enable", "YES");
+		&init::save_rc_conf("ipnat_rules", $config{'ipnat_conf'});
+		}
+	}
 else {
 	# Create or enable init script
 	local $ipf = &has_command($config{'ipf'});
@@ -1244,7 +1281,7 @@ else {
 	local $start = "$ipf -F a\n".
 		       "$ipf -f $config{'ipf_conf'}";
 	local $stop = "$ipf -F a".
-	&foreign_require("init", "init-lib.pl");
+	&foreign_require("init");
 	&init::enable_at_boot($init_script, "Activate IPfilter firewall",
 			      $start, $stop);
 	}
@@ -1264,6 +1301,12 @@ if ($config{'smf'}) {
 				    [ $config{'smf'} ]);
 		}
 	}
+elsif ($gconfig{'os_type'} eq 'freebsd') {
+	# Use built-in config
+	&foreign_require("init");
+	&init::save_rc_conf("ipfilter_enable", "NO");
+	&init::save_rc_conf("ipnat_enable", "NO");
+	}
 else {
 	# Disable init script
 	&foreign_require("init", "init-lib.pl");
