@@ -8,15 +8,14 @@ do 'ldap-useradmin-lib.pl';
 # For mode 0, returns 1 if installed, 0 if not
 sub is_installed
 {
-if ($config{'auth_ldap'}) {
-	return 0 if (!-r $config{'auth_ldap'});
+my $cfile = &ldap_client::get_ldap_config_file();
+if ($cfile) {
+	return 0 if (!-r $cfile);
 	}
-else {
-	if ($_[0]) {
-		return 1 if (!$config{'ldap_host'} || !$config{'login'} ||
-			     !$config{'pass'} || !$config{'user_base'} ||
-			     !$config{'group_base'});
-		}
+elsif ($_[0]) {
+	return 1 if (!$config{'ldap_host'} || !$config{'login'} ||
+		     (!$config{'pass'} && !$config{'ldap_pass_file'}) || 
+		     !$config{'user_base'} || !$config{'group_base'});
 	}
 if ($_[0]) {
 	return 2 if ($got_net_ldap);
