@@ -1,2 +1,2 @@
-desc_pl=Aktualizacja pakietów oprogramowania
+desc_pl=Aktualizacje pakietów oprogramowania
 longdesc_pl=Wyświetla dostępne aktualizacje pakietów z YUM, APT lub innego systemowego menadżera pakietów
